Rohde & Schwarz SMCV100B Vector Signal Generator RsSmcv instrument driver.

Supported instruments: SMCV100B

The package is hosted here: https://pypi.org/project/RsSmcv/

Documentation: https://RsSmcv.readthedocs.io/

Examples: https://github.com/Rohde-Schwarz/Examples/tree/main/SignalGenerators/Python/RsSmcv_ScpiPackage

----------------------------------------------------------------------------------

Release Notes:

Latest release notes summary: Update for FW 5.00.122

Version 5.0.122.13

- Update for FW 5.00.122

Version 4.80.2.11

- Fixed bug in interfaces with the name 'base', new docu format

Version 4.80.2.6

- First released version
